==> fap-0.8.1.tar.bz2: fap-0.8.1/src/audio/input/metaData.h <==
/*
 *  Copyright (C) 2010 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef METADATA_H
#define METADATA_H

#include "fx.h"

class metaData {

public:
enum mpris_t {
	LOCATION,
	TITLE,
	ARTIST,
	ALBUM,
	TRACK,
	TIME,
	MTIME,
	GENRE,
	COMMENT,
	RATING,
	YEAR,
	ARTURL,
	LAST_ID
};

public:
	virtual const unsigned int moreInfo(const unsigned int i) const =0;
	virtual const char* getKey(const unsigned int num) const =0;
	virtual const char* getKey(const mpris_t info) const =0;
	virtual const char* getInfo(unsigned int num) const =0;
	virtual const char* getInfo(const char* info) const =0;
	virtual const char* getInfo(const mpris_t info) const =0;
};

/*****************************************************************/

class metaDataImpl : public metaData {

private:
	static const char* mprisTags[LAST_ID];

private:
	FXStringDict	_infos;

public:
	/// Append song info
	void addInfo(const char* type, const char* info);
	void addInfo(const char* type, unsigned int info);
	void addInfo(const mpris_t type, const char* info);
	void addInfo(const mpris_t type, unsigned int info);

	/// Remove all info
	void clearInfo() { _infos.clear(); }

	/// Find song info
	const FXchar* findInfo(const char* type) const { return _infos.find(type); }

	/// Get song info
	const unsigned int moreInfo(const unsigned int i) const;

	const char* getKey(const unsigned int num) const { return _infos.key(num); }
	const char* getKey(const mpris_t info) const { return mprisTags[info]; }
	const char* getInfo(const unsigned int num) const { return _infos.data(num); }
	const char* getInfo(const char* info) const { return _infos.find(info); }
	const char* getInfo(const mpris_t info) const { return getInfo(mprisTags[info]); }
};

#endif

==> fap_0.8.8.orig.tar.bz2: fap-0.8.8/src/audio/input/metaData.h <==
/*
 *  Copyright (C) 2010 Leandro Nini
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef METADATA_H
#define METADATA_H

#include <fx.h>

class metaData {

public:
enum mpris_t {
	LOCATION,
	TITLE,
	ARTIST,
	ALBUM,
	TRACK,
	TIME,
	MTIME,
	GENRE,
	COMMENT,
	RATING,
	YEAR,
	ARTURL,
	LAST_ID
};

public:
	virtual const int moreInfo(const int i) const =0;
	virtual const char* getKey(const unsigned int num) const =0;
	virtual const char* getKey(const mpris_t info) const =0;
	virtual const char* getInfo(unsigned int num) const =0;
	virtual const char* getInfo(const char* info) const =0;
	virtual const char* getInfo(const mpris_t info) const =0;
};

/*****************************************************************/

class metaDataImpl : public metaData {

private:
	static const char* mprisTags[LAST_ID];

private:
	FXStringDict	_infos;

public:
	/// Append song info
	void addInfo(const char* type, const char* info);
	void addInfo(const char* type, unsigned int info);
	void addInfo(const mpris_t type, const char* info);
	void addInfo(const mpris_t type, unsigned int info);

	/// Remove all info
	void clearInfo() { _infos.clear(); }

	/// Find song info
	const FXchar* findInfo(const char* type) const { return _infos.find(type); }

	/// Get song info
	const int moreInfo(const int i) const;

	const char* getKey(const unsigned int num) const { return _infos.key(num); }
	const char* getKey(const mpris_t info) const { return mprisTags[info]; }
	const char* getInfo(const unsigned int num) const { return _infos.data(num); }
	const char* getInfo(const char* info) const { return _infos.find(info); }
	const char* getInfo(const mpris_t info) const { return getInfo(mprisTags[info]); }
};

#endif
